GnsConnectionRealTimeStatus

Struct GnsConnectionRealTimeStatus 

pub struct GnsConnectionRealTimeStatus(/* private fields */);

Implementations

Source

impl GnsConnectionRealTimeStatus

pub fn state(&self) -> ESteamNetworkingConnectionState

pub fn ping(&self) -> u32

pub fn quality_local(&self) -> f32

pub fn quality_remote(&self) -> f32

pub fn out_packets_per_sec(&self) -> f32

pub fn out_bytes_per_sec(&self) -> f32

pub fn in_packets_per_sec(&self) -> f32

pub fn in_bytes_per_sec(&self) -> f32

pub fn send_rate_bytes_per_sec(&self) -> u32

pub fn pending_bytes_unreliable(&self) -> u32

pub fn pending_bytes_reliable(&self) -> u32

pub fn bytes_sent_unacked_reliable(&self) -> u32

pub fn approximated_queue_time(&self) -> Duration

pub fn max_jitter_usec(&self) -> Option<i32>

Returns the highest packet jitter experienced since the last time this information was fetched. The high water mark is cleared each time you fetch the info.

Returns None if no jitter data is available (the underlying value is negative), or if the connection type doesn’t support jitter measurement.