pub struct GnsLane {
pub priority: i32,
pub weight: u16,
}Expand description
A connection lane.
priority is a signed C int where a lower value means a higher priority.
weight is the relative scheduling weight within one priority class.
Fields
priority: i32weight: u16Implementations