pub struct GnsConnectionRealTimeStatus(/* private fields */);Implementations
Sourceimpl GnsConnectionRealTimeStatus
impl GnsConnectionRealTimeStatus
pub fn state(&self) -> ESteamNetworkingConnectionState
pub fn ping(&self) -> u32
pub fn quality_local(&self) -> f32
pub fn quality_remote(&self) -> f32
pub fn out_packets_per_sec(&self) -> f32
pub fn out_bytes_per_sec(&self) -> f32
pub fn in_packets_per_sec(&self) -> f32
pub fn in_bytes_per_sec(&self) -> f32
pub fn send_rate_bytes_per_sec(&self) -> u32
pub fn pending_bytes_unreliable(&self) -> u32
pub fn pending_bytes_reliable(&self) -> u32
pub fn bytes_sent_unacked_reliable(&self) -> u32
pub fn approximated_queue_time(&self) -> Duration
Sourcepub fn max_jitter_usec(&self) -> Option<i32>
pub fn max_jitter_usec(&self) -> Option<i32>
Returns the highest packet jitter seen since the last time you read this value. Reading it clears the high water mark.
Returns None if no jitter data is available, which happens when the
underlying value is negative or the connection type does not measure
jitter.