pub struct GnsUtils(/* private fields */);Implementations
Sourceimpl GnsUtils
impl GnsUtils
pub fn enable_debug_output( &self, ty: ESteamNetworkingSocketsDebugOutputType, f: fn(ty: ESteamNetworkingSocketsDebugOutputType, msg: String), )
Sourcepub fn allocate_message(
&self,
conn: GnsConnection,
flags: i32,
payload: &[u8],
) -> GnsNetworkMessage<ToSend>
pub fn allocate_message( &self, conn: GnsConnection, flags: i32, payload: &[u8], ) -> GnsNetworkMessage<ToSend>
Allocate a new message to be sent.
This message must be sent if allocated, as the message can only be freed by the GnsSocket::send_messages call.
Sourcepub fn set_global_config_value<'a>(
&self,
typ: ESteamNetworkingConfigValue,
value: GnsConfig<'a>,
) -> Result<(), ()>
pub fn set_global_config_value<'a>( &self, typ: ESteamNetworkingConfigValue, value: GnsConfig<'a>, ) -> Result<(), ()>
Set a global configuration value, i.e. k_ESteamNetworkingConfig_FakePacketLag_Send => 1000 ms
Sourcepub fn set_connection_config_value<'a>(
&self,
conn: GnsConnection,
typ: ESteamNetworkingConfigValue,
value: GnsConfig<'a>,
) -> Result<(), ()>
pub fn set_connection_config_value<'a>( &self, conn: GnsConnection, typ: ESteamNetworkingConfigValue, value: GnsConfig<'a>, ) -> Result<(), ()>
Set a per-connection configuration value, e.g. k_ESteamNetworkingConfig_SendRateMin/Max on an individual accepted connection